@@ -30,9 +30,7 @@ class Selector:
         """
         put_dict = state.dict(exclude_unset=True)
         put_dict["fast"] = fast
-        self.session.put(
-            f"lights/{self.selector}/state", put_dict
-        )
+        self.session.put(f"lights/{self.selector}/state", put_dict)
         self._update_lights()
 
     def state_delta(self, state_delta: model.StateDelta) -> None:
